# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/common.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from blickfeld import options_pb2 as blickfeld_dot_options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/common.proto',
  package='blickfeld.protocol',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16\x62lickfeld/common.proto\x12\x12\x62lickfeld.protocol\x1a\x17\x62lickfeld/options.proto\".\n\nValueRange\x12\x0f\n\x07minimum\x18\x01 \x01(\x02\x12\x0f\n\x07maximum\x18\x02 \x01(\x02\"B\n\x12OptionalValueRange\x12\x15\n\x07minimum\x18\x01 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\x15\n\x07maximum\x18\x02 \x01(\x02\x42\x04\xb0\xb5\x18\x01\"P\n\x0fSoftwareVersion\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x08revision\x18\x02 \x01(\tB\x04\xb0\xb5\x18\x01\x12\x17\n\tci_job_id\x18\x03 \x01(\rB\x04\xb0\xb5\x18\x01\"\x98\x01\n\x0eHardwareModule\x12.\n\rserial_number\x18\x01 \x01(\tB\x17\xb0\xb5\x18\x01\xaa\xb5\x18\x0b[A-Z2-7]{9}\xd0\xb5\x18\x02\x12$\n\x14legacy_serial_number\x18\x02 \x01(\tB\x06\x18\x01\xb0\xb5\x18\x01\x12\x30\n\x07version\x18\x03 \x01(\tB\x1f\xb0\xb5\x18\x01\xaa\xb5\x18\x17v[0-9]+\\.[0-9]+\\.[0-9]+\"\x8f\x01\n\x05\x46ield\x12\x39\n\x0bidentifiers\x18\x01 \x03(\x0b\x32$.blickfeld.protocol.Field.Identifier\x12\r\n\x05scale\x18\x02 \x01(\x02\x1a<\n\nIdentifier\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x15\n\rcamelcase_key\x18\x03 \x01(\t\"\xe5\x02\n\nConstraint\x12)\n\x06target\x18\x01 \x01(\x0b\x32\x19.blickfeld.protocol.Field\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12;\n\x08\x63onstant\x18\n \x01(\x0b\x32\'.blickfeld.protocol.Constraint.ConstantH\x00\x12?\n\npolynomial\x18\x0b \x01(\x0b\x32).blickfeld.protocol.Constraint.PolynomialH\x00\x1a\x38\n\x08\x43onstant\x12\x15\n\x07minimum\x18\x01 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\x15\n\x07maximum\x18\x02 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x1a\\\n\nPolynomial\x12,\n\treference\x18\x01 \x01(\x0b\x32\x19.blickfeld.protocol.Field\x12\x0f\n\x07minimum\x18\x02 \x03(\x02\x12\x0f\n\x07maximum\x18\x03 \x03(\x02\x42\x06\n\x04type*/\n\x08Language\x12\x07\n\x03\x43PP\x10\x01\x12\n\n\x06PYTHON\x10\x02\x12\x0e\n\nTYPESCRIPT\x10\x03'
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,])

_LANGUAGE = _descriptor.EnumDescriptor(
  name='Language',
  full_name='blickfeld.protocol.Language',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CPP', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PYTHON', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TYPESCRIPT', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=930,
  serialized_end=977,
)
_sym_db.RegisterEnumDescriptor(_LANGUAGE)

Language = enum_type_wrapper.EnumTypeWrapper(_LANGUAGE)
CPP = 1
PYTHON = 2
TYPESCRIPT = 3



_VALUERANGE = _descriptor.Descriptor(
  name='ValueRange',
  full_name='blickfeld.protocol.ValueRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='minimum', full_name='blickfeld.protocol.ValueRange.minimum', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum', full_name='blickfeld.protocol.ValueRange.maximum', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=117,
)


_OPTIONALVALUERANGE = _descriptor.Descriptor(
  name='OptionalValueRange',
  full_name='blickfeld.protocol.OptionalValueRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='minimum', full_name='blickfeld.protocol.OptionalValueRange.minimum', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum', full_name='blickfeld.protocol.OptionalValueRange.maximum', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=185,
)


_SOFTWAREVERSION = _descriptor.Descriptor(
  name='SoftwareVersion',
  full_name='blickfeld.protocol.SoftwareVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blickfeld.protocol.SoftwareVersion.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revision', full_name='blickfeld.protocol.SoftwareVersion.revision', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ci_job_id', full_name='blickfeld.protocol.SoftwareVersion.ci_job_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=187,
  serialized_end=267,
)


_HARDWAREMODULE = _descriptor.Descriptor(
  name='HardwareModule',
  full_name='blickfeld.protocol.HardwareModule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='blickfeld.protocol.HardwareModule.serial_number', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001\252\265\030\013[A-Z2-7]{9}\320\265\030\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='legacy_serial_number', full_name='blickfeld.protocol.HardwareModule.legacy_serial_number', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='blickfeld.protocol.HardwareModule.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001\252\265\030\027v[0-9]+\\.[0-9]+\\.[0-9]+', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=422,
)


_FIELD_IDENTIFIER = _descriptor.Descriptor(
  name='Identifier',
  full_name='blickfeld.protocol.Field.Identifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blickfeld.protocol.Field.Identifier.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='blickfeld.protocol.Field.Identifier.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camelcase_key', full_name='blickfeld.protocol.Field.Identifier.camelcase_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=508,
  serialized_end=568,
)

_FIELD = _descriptor.Descriptor(
  name='Field',
  full_name='blickfeld.protocol.Field',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifiers', full_name='blickfeld.protocol.Field.identifiers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale', full_name='blickfeld.protocol.Field.scale', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FIELD_IDENTIFIER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=425,
  serialized_end=568,
)


_CONSTRAINT_CONSTANT = _descriptor.Descriptor(
  name='Constant',
  full_name='blickfeld.protocol.Constraint.Constant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='minimum', full_name='blickfeld.protocol.Constraint.Constant.minimum', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum', full_name='blickfeld.protocol.Constraint.Constant.maximum', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=826,
)

_CONSTRAINT_POLYNOMIAL = _descriptor.Descriptor(
  name='Polynomial',
  full_name='blickfeld.protocol.Constraint.Polynomial',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference', full_name='blickfeld.protocol.Constraint.Polynomial.reference', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minimum', full_name='blickfeld.protocol.Constraint.Polynomial.minimum', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum', full_name='blickfeld.protocol.Constraint.Polynomial.maximum', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=828,
  serialized_end=920,
)

_CONSTRAINT = _descriptor.Descriptor(
  name='Constraint',
  full_name='blickfeld.protocol.Constraint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='blickfeld.protocol.Constraint.target', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='blickfeld.protocol.Constraint.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constant', full_name='blickfeld.protocol.Constraint.constant', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polynomial', full_name='blickfeld.protocol.Constraint.polynomial', index=3,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONSTRAINT_CONSTANT, _CONSTRAINT_POLYNOMIAL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='blickfeld.protocol.Constraint.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=571,
  serialized_end=928,
)

_FIELD_IDENTIFIER.containing_type = _FIELD
_FIELD.fields_by_name['identifiers'].message_type = _FIELD_IDENTIFIER
_CONSTRAINT_CONSTANT.containing_type = _CONSTRAINT
_CONSTRAINT_POLYNOMIAL.fields_by_name['reference'].message_type = _FIELD
_CONSTRAINT_POLYNOMIAL.containing_type = _CONSTRAINT
_CONSTRAINT.fields_by_name['target'].message_type = _FIELD
_CONSTRAINT.fields_by_name['constant'].message_type = _CONSTRAINT_CONSTANT
_CONSTRAINT.fields_by_name['polynomial'].message_type = _CONSTRAINT_POLYNOMIAL
_CONSTRAINT.oneofs_by_name['type'].fields.append(
  _CONSTRAINT.fields_by_name['constant'])
_CONSTRAINT.fields_by_name['constant'].containing_oneof = _CONSTRAINT.oneofs_by_name['type']
_CONSTRAINT.oneofs_by_name['type'].fields.append(
  _CONSTRAINT.fields_by_name['polynomial'])
_CONSTRAINT.fields_by_name['polynomial'].containing_oneof = _CONSTRAINT.oneofs_by_name['type']
DESCRIPTOR.message_types_by_name['ValueRange'] = _VALUERANGE
DESCRIPTOR.message_types_by_name['OptionalValueRange'] = _OPTIONALVALUERANGE
DESCRIPTOR.message_types_by_name['SoftwareVersion'] = _SOFTWAREVERSION
DESCRIPTOR.message_types_by_name['HardwareModule'] = _HARDWAREMODULE
DESCRIPTOR.message_types_by_name['Field'] = _FIELD
DESCRIPTOR.message_types_by_name['Constraint'] = _CONSTRAINT
DESCRIPTOR.enum_types_by_name['Language'] = _LANGUAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ValueRange = _reflection.GeneratedProtocolMessageType('ValueRange', (_message.Message,), {
  'DESCRIPTOR' : _VALUERANGE,
  '__module__' : 'blickfeld.common_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.ValueRange)
  })
_sym_db.RegisterMessage(ValueRange)

OptionalValueRange = _reflection.GeneratedProtocolMessageType('OptionalValueRange', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONALVALUERANGE,
  '__module__' : 'blickfeld.common_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.OptionalValueRange)
  })
_sym_db.RegisterMessage(OptionalValueRange)

SoftwareVersion = _reflection.GeneratedProtocolMessageType('SoftwareVersion', (_message.Message,), {
  'DESCRIPTOR' : _SOFTWAREVERSION,
  '__module__' : 'blickfeld.common_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.SoftwareVersion)
  })
_sym_db.RegisterMessage(SoftwareVersion)

HardwareModule = _reflection.GeneratedProtocolMessageType('HardwareModule', (_message.Message,), {
  'DESCRIPTOR' : _HARDWAREMODULE,
  '__module__' : 'blickfeld.common_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.HardwareModule)
  })
_sym_db.RegisterMessage(HardwareModule)

Field = _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {

  'Identifier' : _reflection.GeneratedProtocolMessageType('Identifier', (_message.Message,), {
    'DESCRIPTOR' : _FIELD_IDENTIFIER,
    '__module__' : 'blickfeld.common_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Field.Identifier)
    })
  ,
  'DESCRIPTOR' : _FIELD,
  '__module__' : 'blickfeld.common_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.Field)
  })
_sym_db.RegisterMessage(Field)
_sym_db.RegisterMessage(Field.Identifier)

Constraint = _reflection.GeneratedProtocolMessageType('Constraint', (_message.Message,), {

  'Constant' : _reflection.GeneratedProtocolMessageType('Constant', (_message.Message,), {
    'DESCRIPTOR' : _CONSTRAINT_CONSTANT,
    '__module__' : 'blickfeld.common_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Constraint.Constant)
    })
  ,

  'Polynomial' : _reflection.GeneratedProtocolMessageType('Polynomial', (_message.Message,), {
    'DESCRIPTOR' : _CONSTRAINT_POLYNOMIAL,
    '__module__' : 'blickfeld.common_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.Constraint.Polynomial)
    })
  ,
  'DESCRIPTOR' : _CONSTRAINT,
  '__module__' : 'blickfeld.common_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.Constraint)
  })
_sym_db.RegisterMessage(Constraint)
_sym_db.RegisterMessage(Constraint.Constant)
_sym_db.RegisterMessage(Constraint.Polynomial)


_OPTIONALVALUERANGE.fields_by_name['minimum']._options = None
_OPTIONALVALUERANGE.fields_by_name['maximum']._options = None
_SOFTWAREVERSION.fields_by_name['revision']._options = None
_SOFTWAREVERSION.fields_by_name['ci_job_id']._options = None
_HARDWAREMODULE.fields_by_name['serial_number']._options = None
_HARDWAREMODULE.fields_by_name['legacy_serial_number']._options = None
_HARDWAREMODULE.fields_by_name['version']._options = None
_CONSTRAINT_CONSTANT.fields_by_name['minimum']._options = None
_CONSTRAINT_CONSTANT.fields_by_name['maximum']._options = None
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.stream.connection_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Advanced(google.protobuf.message.Message):
    """*
    > Introduced in BSL v2.11 and firmware v1.11

    Expert parameters: It is not recommended to adapt this calibrated configuration without understanding the influences on the resulting point cloud quality.

    The current set of parameters is preliminary, additional parameters may be added or may get obsolete in the future.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Detector(google.protobuf.message.Message):
        """*
        The behavior of the detector can be adjusted to improve the performance under extreme environmental conditions, e.g. static setup with strong daylight or basement rooms without daylight.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        SENSITIVITY_FIELD_NUMBER: builtins.int
        sensitivity: builtins.float = ...
        """Relatively influences the sensitivity of the detector. Higher values might also result into range loss. It is recommended to validate the noise filter parameters after changes to this setting."""

        def __init__(self,
            *,
            sensitivity : typing.Optional[builtins.float] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"sensitivity",b"sensitivity"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"sensitivity",b"sensitivity"]) -> None: ...

    class Processing(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.12 and firmware v1.12

        Processing parameters are set at the factory after calibration. Changing these values invalidates the factory calibration.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        RANGE_OFFSET_FIELD_NUMBER: builtins.int
        IMU_STATIC_ROTATION_OFFSET_FIELD_NUMBER: builtins.int
        HORIZONTAL_PHASE_OFFSET_FIELD_NUMBER: builtins.int
        range_offset: builtins.float = ...
        """in [m]"""

        @property
        def imu_static_rotation_offset(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
            """<blockquote>Introduced in BSL v2.19 and firmware v1.20</blockquote> in [rad] - Offset rotation matrix for acceleration of IMU. Can be used to calibrate the accelerometer e.g. on a flat surface."""
            pass
        horizontal_phase_offset: builtins.float = ...
        """<blockquote>Introduced in BSL v2.19.5 and firmware v1.21.1</blockquote> in [s] - Correction for phase offset in the horizontal field of view. This parameter might be adjusted in the field if the upper and lower half of the frame drifted horizontally."""

        def __init__(self,
            *,
            range_offset : typing.Optional[builtins.float] = ...,
            imu_static_rotation_offset : typing.Optional[typing.Iterable[builtins.float]] = ...,
            horizontal_phase_offset : typing.Optional[builtins.float] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"horizontal_phase_offset",b"horizontal_phase_offset",u"range_offset",b"range_offset"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"horizontal_phase_offset",b"horizontal_phase_offset",u"imu_static_rotation_offset",b"imu_static_rotation_offset",u"range_offset",b"range_offset"]) -> None: ...

    class Server(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.13 and firmware v1.13

        Parameters, which control the server behavior.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        DEFAULT_POINT_CLOUD_SUBSCRIPTION_FIELD_NUMBER: builtins.int
        @property
        def default_point_cloud_subscription(self) -> blickfeld.stream.connection_pb2.Subscribe.PointCloud:
            """Overwrite default point cloud subscription. Can still be overridden with client requests."""
            pass
        def __init__(self,
            *,
            default_point_cloud_subscription : typing.Optional[blickfeld.stream.connection_pb2.Subscribe.PointCloud] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"default_point_cloud_subscription",b"default_point_cloud_subscription"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"default_point_cloud_subscription",b"default_point_cloud_subscription"]) -> None: ...

    class TimeSynchronization(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.18 and firmware v1.19

        Activate or deactivate synchronization and change parameters
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class NTP(google.protobuf.message.Message):
            """*
            The Blickfeld devices can use an NTPv4 client to synchronize the local device time to a time server.
            NTP can achieve synchronization accuracy below one millisecond for measurement results in local networks.
            """
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            SERVERS_FIELD_NUMBER: builtins.int
            @property
            def servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
                """Specify list of NTP server. By default, debian pool NTP servers are used."""
                pass
            def __init__(self,
                *,
                servers : typing.Optional[typing.Iterable[typing.Text]] = ...,
                ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"servers",b"servers"]) -> None: ...

        class PTP(google.protobuf.message.Message):
            """*
            The Blickfeld devices can use a PTP client to synchronize the local device time to a time server.
            PTP can achieve an higher accuracy than NTP in local networks.
            """
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            class DelayMechanism(_DelayMechanism, metaclass=_DelayMechanismEnumTypeWrapper):
                pass
            class _DelayMechanism:
                V = typing.NewType('V', builtins.int)
            class _DelayMechanismEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DelayMechanism.V], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
                E2E = Advanced.TimeSynchronization.PTP.DelayMechanism.V(1)
                """End to end delay detection"""

                P2P = Advanced.TimeSynchronization.PTP.DelayMechanism.V(2)
                """Peer to peer delay detection"""


            E2E = Advanced.TimeSynchronization.PTP.DelayMechanism.V(1)
            """End to end delay detection"""

            P2P = Advanced.TimeSynchronization.PTP.DelayMechanism.V(2)
            """Peer to peer delay detection"""


            DOMAIN_FIELD_NUMBER: builtins.int
            DELAY_MECHANISM_FIELD_NUMBER: builtins.int
            UNICAST_DESTINATIONS_FIELD_NUMBER: builtins.int
            domain: builtins.int = ...
            """PTP domain number."""

            delay_mechanism: global___Advanced.TimeSynchronization.PTP.DelayMechanism.V = ...
            """Delay detection mode used"""

            @property
            def unicast_destinations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
                """Specify unicast slave addresses for unicast master operation, or unicast master addresses for slave operation. If this is set unicast mode will be activated."""
                pass
            def __init__(self,
                *,
                domain : typing.Optional[builtins.int] = ...,
                delay_mechanism : typing.Optional[global___Advanced.TimeSynchronization.PTP.DelayMechanism.V] = ...,
                unicast_destinations : typing.Optional[typing.Iterable[typing.Text]] = ...,
                ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal[u"delay_mechanism",b"delay_mechanism",u"domain",b"domain"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"delay_mechanism",b"delay_mechanism",u"domain",b"domain",u"unicast_destinations",b"unicast_destinations"]) -> None: ...

        NTP_FIELD_NUMBER: builtins.int
        PTP_FIELD_NUMBER: builtins.int
        @property
        def ntp(self) -> global___Advanced.TimeSynchronization.NTP:
            """If this field is set, NTP synchronization is activated, which is the default configuration. Refer to [NTP](#blickfeld.protocol.config.Advanced.Synchronization.NTP)"""
            pass
        @property
        def ptp(self) -> global___Advanced.TimeSynchronization.PTP:
            """If this field is set, PTP synchronization is activated and NTP synchronization is deactivated. Refer to [PTP](#blickfeld.protocol.config.Advanced.Synchronization.PTP)"""
            pass
        def __init__(self,
            *,
            ntp : typing.Optional[global___Advanced.TimeSynchronization.NTP] = ...,
            ptp : typing.Optional[global___Advanced.TimeSynchronization.PTP] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"kind",b"kind",u"ntp",b"ntp",u"ptp",b"ptp"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"kind",b"kind",u"ntp",b"ntp",u"ptp",b"ptp"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal[u"kind",b"kind"]) -> typing.Optional[typing_extensions.Literal["ntp","ptp"]]: ...

    DETECTOR_FIELD_NUMBER: builtins.int
    PROCESSING_FIELD_NUMBER: builtins.int
    SERVER_FIELD_NUMBER: builtins.int
    TIME_SYNCHRONIZATION_FIELD_NUMBER: builtins.int
    @property
    def detector(self) -> global___Advanced.Detector:
        """Refer to [Detector](#blickfeld.protocol.config.Advanced.Detector)"""
        pass
    @property
    def processing(self) -> global___Advanced.Processing:
        """<blockquote>Introduced in BSL v2.12 and firmware v1.12</blockquote> Refer to [Processing](#blickfeld.protocol.config.Advanced.Processing)"""
        pass
    @property
    def server(self) -> global___Advanced.Server:
        """<blockquote>Introduced in BSL v2.13 and firmware v1.13</blockquote> Refer to [Server](#blickfeld.protocol.config.Advanced.Server)"""
        pass
    @property
    def time_synchronization(self) -> global___Advanced.TimeSynchronization:
        """<blockquote>Introduced in BSL v2.18 and firmware v1.19</blockquote> Refer to [TimeSynchronization](#blickfeld.protocol.config.Advanced.TimeSynchronization)"""
        pass
    def __init__(self,
        *,
        detector : typing.Optional[global___Advanced.Detector] = ...,
        processing : typing.Optional[global___Advanced.Processing] = ...,
        server : typing.Optional[global___Advanced.Server] = ...,
        time_synchronization : typing.Optional[global___Advanced.TimeSynchronization] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"detector",b"detector",u"processing",b"processing",u"server",b"server",u"time_synchronization",b"time_synchronization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"detector",b"detector",u"processing",b"processing",u"server",b"server",u"time_synchronization",b"time_synchronization"]) -> None: ...
global___Advanced = Advanced



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: a42_proto/frame.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from blickfeld.data import frame_pb2 as blickfeld_dot_data_dot_frame__pb2
from bf_proto.percept.output import output_pb2 as bf__proto_dot_percept_dot_output_dot_output__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='a42_proto/frame.proto',
  package='sensors',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15\x61\x34\x32_proto/frame.proto\x12\x07sensors\x1a\x1a\x62lickfeld/data/frame.proto\x1a$bf_proto/percept/output/output.proto\"\x1b\n\tTransform\x12\x0e\n\x06matrix\x18\x01 \x03(\x01\"\xb3\x01\n\x10LaserCalibration\x12%\n\textrinsic\x18\x01 \x01(\x0b\x32\x12.sensors.Transform\x12\x14\n\x0cvertical_fov\x18\x02 \x01(\x01\x12\x16\n\x0ehorizontal_fov\x18\x03 \x01(\x01\x12 \n\x18horizontal_angle_spacing\x18\x04 \x01(\x01\x12\x12\n\nframe_mode\x18\x05 \x01(\t\x12\x14\n\x0cscan_pattern\x18\x06 \x01(\t\"\x8d\x01\n\x05Laser\x12&\n\nlaser_name\x18\x01 \x02(\x0e\x32\x12.sensors.LaserName\x12,\n\x04\x64\x61ta\x18\x02 \x02(\x0b\x32\x1e.blickfeld.protocol.data.Frame\x12.\n\x0b\x63\x61libration\x18\x03 \x01(\x0b\x32\x19.sensors.LaserCalibration\"x\n\x05\x46rame\x12\x14\n\x0ctimestamp_ns\x18\x01 \x02(\x04\x12\x1e\n\x06lasers\x18\x02 \x03(\x0b\x32\x0e.sensors.Laser\x12\x39\n\x0bobject_list\x18\x03 \x01(\x0b\x32$.blickfeld.percept.output.ObjectList*D\n\tLaserName\x12\x16\n\x12LASER_NAME_UNKNOWN\x10\x00\x12\t\n\x05\x46RONT\x10\x01\x12\n\n\x06MIDDLE\x10\x02\x12\x08\n\x04\x42\x41\x43K\x10\x03'
  ,
  dependencies=[blickfeld_dot_data_dot_frame__pb2.DESCRIPTOR,bf__proto_dot_percept_dot_output_dot_output__pb2.DESCRIPTOR,])

_LASERNAME = _descriptor.EnumDescriptor(
  name='LaserName',
  full_name='sensors.LaserName',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LASER_NAME_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRONT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIDDLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BACK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=577,
  serialized_end=645,
)
_sym_db.RegisterEnumDescriptor(_LASERNAME)

LaserName = enum_type_wrapper.EnumTypeWrapper(_LASERNAME)
LASER_NAME_UNKNOWN = 0
FRONT = 1
MIDDLE = 2
BACK = 3



_TRANSFORM = _descriptor.Descriptor(
  name='Transform',
  full_name='sensors.Transform',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='matrix', full_name='sensors.Transform.matrix', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=127,
)


_LASERCALIBRATION = _descriptor.Descriptor(
  name='LaserCalibration',
  full_name='sensors.LaserCalibration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='extrinsic', full_name='sensors.LaserCalibration.extrinsic', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vertical_fov', full_name='sensors.LaserCalibration.vertical_fov', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='horizontal_fov', full_name='sensors.LaserCalibration.horizontal_fov', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='horizontal_angle_spacing', full_name='sensors.LaserCalibration.horizontal_angle_spacing', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_mode', full_name='sensors.LaserCalibration.frame_mode', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scan_pattern', full_name='sensors.LaserCalibration.scan_pattern', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=309,
)


_LASER = _descriptor.Descriptor(
  name='Laser',
  full_name='sensors.Laser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='laser_name', full_name='sensors.Laser.laser_name', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='sensors.Laser.data', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibration', full_name='sensors.Laser.calibration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=453,
)


_FRAME = _descriptor.Descriptor(
  name='Frame',
  full_name='sensors.Frame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_ns', full_name='sensors.Frame.timestamp_ns', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lasers', full_name='sensors.Frame.lasers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_list', full_name='sensors.Frame.object_list', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=575,
)

_LASERCALIBRATION.fields_by_name['extrinsic'].message_type = _TRANSFORM
_LASER.fields_by_name['laser_name'].enum_type = _LASERNAME
_LASER.fields_by_name['data'].message_type = blickfeld_dot_data_dot_frame__pb2._FRAME
_LASER.fields_by_name['calibration'].message_type = _LASERCALIBRATION
_FRAME.fields_by_name['lasers'].message_type = _LASER
_FRAME.fields_by_name['object_list'].message_type = bf__proto_dot_percept_dot_output_dot_output__pb2._OBJECTLIST
DESCRIPTOR.message_types_by_name['Transform'] = _TRANSFORM
DESCRIPTOR.message_types_by_name['LaserCalibration'] = _LASERCALIBRATION
DESCRIPTOR.message_types_by_name['Laser'] = _LASER
DESCRIPTOR.message_types_by_name['Frame'] = _FRAME
DESCRIPTOR.enum_types_by_name['LaserName'] = _LASERNAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Transform = _reflection.GeneratedProtocolMessageType('Transform', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORM,
  '__module__' : 'a42_proto.frame_pb2'
  # @@protoc_insertion_point(class_scope:sensors.Transform)
  })
_sym_db.RegisterMessage(Transform)

LaserCalibration = _reflection.GeneratedProtocolMessageType('LaserCalibration', (_message.Message,), {
  'DESCRIPTOR' : _LASERCALIBRATION,
  '__module__' : 'a42_proto.frame_pb2'
  # @@protoc_insertion_point(class_scope:sensors.LaserCalibration)
  })
_sym_db.RegisterMessage(LaserCalibration)

Laser = _reflection.GeneratedProtocolMessageType('Laser', (_message.Message,), {
  'DESCRIPTOR' : _LASER,
  '__module__' : 'a42_proto.frame_pb2'
  # @@protoc_insertion_point(class_scope:sensors.Laser)
  })
_sym_db.RegisterMessage(Laser)

Frame = _reflection.GeneratedProtocolMessageType('Frame', (_message.Message,), {
  'DESCRIPTOR' : _FRAME,
  '__module__' : 'a42_proto.frame_pb2'
  # @@protoc_insertion_point(class_scope:sensors.Frame)
  })
_sym_db.RegisterMessage(Frame)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bf_proto/percept/data/point_cloud_transform.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bf_proto.percept.common import geometry_pb2 as bf__proto_dot_percept_dot_common_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='bf_proto/percept/data/point_cloud_transform.proto',
  package='blickfeld.percept.data',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1bf_proto/percept/data/point_cloud_transform.proto\x12\x16\x62lickfeld.percept.data\x1a&bf_proto/percept/common/geometry.proto\"m\n\x13PointCloudTransform\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0e\n\x06target\x18\x02 \x01(\t\x12\x36\n\ttransform\x18\x03 \x01(\x0b\x32#.blickfeld.percept.common.Transformb\x06proto3'
  ,
  dependencies=[bf__proto_dot_percept_dot_common_dot_geometry__pb2.DESCRIPTOR,])




_POINTCLOUDTRANSFORM = _descriptor.Descriptor(
  name='PointCloudTransform',
  full_name='blickfeld.percept.data.PointCloudTransform',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='blickfeld.percept.data.PointCloudTransform.source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='blickfeld.percept.data.PointCloudTransform.target', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transform', full_name='blickfeld.percept.data.PointCloudTransform.transform', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=226,
)

_POINTCLOUDTRANSFORM.fields_by_name['transform'].message_type = bf__proto_dot_percept_dot_common_dot_geometry__pb2._TRANSFORM
DESCRIPTOR.message_types_by_name['PointCloudTransform'] = _POINTCLOUDTRANSFORM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PointCloudTransform = _reflection.GeneratedProtocolMessageType('PointCloudTransform', (_message.Message,), {
  'DESCRIPTOR' : _POINTCLOUDTRANSFORM,
  '__module__' : 'bf_proto.percept.data.point_cloud_transform_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.data.PointCloudTransform)
  })
_sym_db.RegisterMessage(PointCloudTransform)


# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.common_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Client(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LIBRARY_VERSION_FIELD_NUMBER: builtins.int
    FILE_TIME_NS_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    library_version: typing.Text = ...
    """Library version"""

    file_time_ns: builtins.int = ...
    """Unit: [ns] - File time stamp"""

    language: blickfeld.common_pb2.Language.V = ...
    """Used library language for file creation"""

    def __init__(self,
        *,
        library_version : typing.Optional[typing.Text] = ...,
        file_time_ns : typing.Optional[builtins.int] = ...,
        language : typing.Optional[blickfeld.common_pb2.Language.V] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"file_time_ns",b"file_time_ns",u"language",b"language",u"library_version",b"library_version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"file_time_ns",b"file_time_ns",u"language",b"language",u"library_version",b"library_version"]) -> None: ...
global___Client = Client



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bf_proto.percept.common.geometric_shapes_pb2
import bf_proto.percept.common.geometry_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Object(google.protobuf.message.Message):
    """*
    A message representing exactly one object.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Classification(google.protobuf.message.Message):
        """*
        Classification of an object.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class Type(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            ID_FIELD_NUMBER: builtins.int
            CONFIDENCE_FIELD_NUMBER: builtins.int
            id: builtins.int = ...
            """id of the object class"""

            confidence: builtins.float = ...
            """Confidence level of the class."""

            def __init__(self,
                *,
                id : builtins.int = ...,
                confidence : builtins.float = ...,
                ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"confidence",b"confidence",u"id",b"id"]) -> None: ...

        TYPES_FIELD_NUMBER: builtins.int
        @property
        def types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Object.Classification.Type]: ...
        def __init__(self,
            *,
            types : typing.Optional[typing.Iterable[global___Object.Classification.Type]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"types",b"types"]) -> None: ...

    TIMESTAMP_FIELD_NUMBER: builtins.int
    UUID_FIELD_NUMBER: builtins.int
    POSE_FIELD_NUMBER: builtins.int
    LINEAR_VELOCITY_FIELD_NUMBER: builtins.int
    ANGULAR_VELOCITY_FIELD_NUMBER: builtins.int
    SHAPE_FIELD_NUMBER: builtins.int
    CLASSIFICATION_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of measurement."""
        pass
    uuid: typing.Text = ...
    """A UUID, with which the object can be identified."""

    @property
    def pose(self) -> bf_proto.percept.common.geometry_pb2.Pose:
        """The position and orientation of the object."""
        pass
    @property
    def linear_velocity(self) -> bf_proto.percept.common.geometry_pb2.Vector3:
        """The linear velocity of the object."""
        pass
    @property
    def angular_velocity(self) -> bf_proto.percept.common.geometry_pb2.Vector3:
        """The angular velocity of the object."""
        pass
    @property
    def shape(self) -> bf_proto.percept.common.geometric_shapes_pb2.Shape:
        """The shape representing the object (bounding box)."""
        pass
    @property
    def classification(self) -> global___Object.Classification:
        """Classification information of the object."""
        pass
    @property
    def path(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bf_proto.percept.common.geometry_pb2.Pose]:
        """List of the last poses including the current pose"""
        pass
    def __init__(self,
        *,
        timestamp : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        uuid : typing.Text = ...,
        pose : typing.Optional[bf_proto.percept.common.geometry_pb2.Pose] = ...,
        linear_velocity : typing.Optional[bf_proto.percept.common.geometry_pb2.Vector3] = ...,
        angular_velocity : typing.Optional[bf_proto.percept.common.geometry_pb2.Vector3] = ...,
        shape : typing.Optional[bf_proto.percept.common.geometric_shapes_pb2.Shape] = ...,
        classification : typing.Optional[global___Object.Classification] = ...,
        path : typing.Optional[typing.Iterable[bf_proto.percept.common.geometry_pb2.Pose]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"angular_velocity",b"angular_velocity",u"classification",b"classification",u"linear_velocity",b"linear_velocity",u"pose",b"pose",u"shape",b"shape",u"timestamp",b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"angular_velocity",b"angular_velocity",u"classification",b"classification",u"linear_velocity",b"linear_velocity",u"path",b"path",u"pose",b"pose",u"shape",b"shape",u"timestamp",b"timestamp",u"uuid",b"uuid"]) -> None: ...
global___Object = Object



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class IMU(google.protobuf.message.Message):
    """*
    > Introduced in BSL v2.18 and firmware v1.19

    The Cube has an on-board IMU, which can be used for e.g. mapping applications or static auto-leveling.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Sample(google.protobuf.message.Message):
        """*
        Describes a single IMU state.
        Data rate is approx. 1.125 khz.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        START_OFFSET_NS_FIELD_NUMBER: builtins.int
        ACCELERATION_FIELD_NUMBER: builtins.int
        ANGULAR_VELOCITY_FIELD_NUMBER: builtins.int
        start_offset_ns: builtins.int = ...
        """Unit: [ns] – Offset to [start_time_ns](#blickfeld.protocol.data.IMU.start_time_ns)"""

        @property
        def acceleration(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
            """Unit: [g] - Format: [x,y,z] - Measured acceleration for 3-axes."""
            pass
        @property
        def angular_velocity(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
            """Unit: [rad/s] - Format: [x,y,z] - Measured angular velocity by gyroscope for 3-axes."""
            pass
        def __init__(self,
            *,
            start_offset_ns : typing.Optional[builtins.int] = ...,
            acceleration : typing.Optional[typing.Iterable[builtins.float]] = ...,
            angular_velocity : typing.Optional[typing.Iterable[builtins.float]] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"start_offset_ns",b"start_offset_ns"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"acceleration",b"acceleration",u"angular_velocity",b"angular_velocity",u"start_offset_ns",b"start_offset_ns"]) -> None: ...

    class Packed(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        LENGTH_FIELD_NUMBER: builtins.int
        START_OFFSET_NS_FIELD_NUMBER: builtins.int
        ACCELERATION_FIELD_NUMBER: builtins.int
        ANGULAR_VELOCITY_FIELD_NUMBER: builtins.int
        length: builtins.int = ...
        """Length of arrays"""

        start_offset_ns: builtins.bytes = ...
        """Starting time of the point in relation to [Data.start_time_ns](#blickfeld.protocol.data.IMU.Data.start_time_ns). 1-dimensional array. Unit: [ns]. Type: UInt64. Byte Order: Big Endian."""

        acceleration: builtins.bytes = ...
        """Accerlation. 3-dimensional array in row-major format with [x, y, z] tuples. Unit: [g]. Type: Float32. Byte Order: Big Endian."""

        angular_velocity: builtins.bytes = ...
        """Angular velocity, measured with gyroscope. 3-dimensional array in row-major format with [x, y, z] tuples. Unit: [rad/s]. Type: Float32. Byte Order: Big Endian."""

        def __init__(self,
            *,
            length : typing.Optional[builtins.int] = ...,
            start_offset_ns : typing.Optional[builtins.bytes] = ...,
            acceleration : typing.Optional[builtins.bytes] = ...,
            angular_velocity : typing.Optional[builtins.bytes] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"acceleration",b"acceleration",u"angular_velocity",b"angular_velocity",u"length",b"length",u"start_offset_ns",b"start_offset_ns"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"acceleration",b"acceleration",u"angular_velocity",b"angular_velocity",u"length",b"length",u"start_offset_ns",b"start_offset_ns"]) -> None: ...

    START_TIME_NS_FIELD_NUMBER: builtins.int
    SAMPLES_FIELD_NUMBER: builtins.int
    PACKED_FIELD_NUMBER: builtins.int
    start_time_ns: builtins.int = ...
    """Unit: [ns] – start timestamp of data. The start_offset_ns in each sample refers to this value. The timestamp is synchronized to the ones in point cloud frames."""

    @property
    def samples(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IMU.Sample]:
        """Refer to [Sample](#blickfeld.protocol.data.IMU.Sample)"""
        pass
    @property
    def packed(self) -> global___IMU.Packed:
        """Refer to [Packed](#blickfeld.protocol.data.IMU.Packed)"""
        pass
    def __init__(self,
        *,
        start_time_ns : typing.Optional[builtins.int] = ...,
        samples : typing.Optional[typing.Iterable[global___IMU.Sample]] = ...,
        packed : typing.Optional[global___IMU.Packed] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"packed",b"packed",u"start_time_ns",b"start_time_ns"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"packed",b"packed",u"samples",b"samples",u"start_time_ns",b"start_time_ns"]) -> None: ...
global___IMU = IMU



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Temperature(google.protobuf.message.Message):
    """*
    This section describes the temperature of the hardware modules in the device.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Sensor(_Sensor, metaclass=_SensorEnumTypeWrapper):
        """*
        This section describes the hardware modules in the device.
        """
        pass
    class _Sensor:
        V = typing.NewType('V', builtins.int)
    class _SensorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Sensor.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNKNOWN = Temperature.Sensor.V(0)
        LDM = Temperature.Sensor.V(1)
        """Laser and detector module"""

        ETHERNET = Temperature.Sensor.V(2)
        """Ethernet adapter"""

        MSB = Temperature.Sensor.V(3)
        """Mixed signal board"""

        PL = Temperature.Sensor.V(4)
        """Programmable logic"""

        PS = Temperature.Sensor.V(5)
        """Processing system"""

        SCANNER_SMALL = Temperature.Sensor.V(6)
        """Vertical mirror"""

        SCANNER_BIG = Temperature.Sensor.V(7)
        """Horizontal mirror"""


    UNKNOWN = Temperature.Sensor.V(0)
    LDM = Temperature.Sensor.V(1)
    """Laser and detector module"""

    ETHERNET = Temperature.Sensor.V(2)
    """Ethernet adapter"""

    MSB = Temperature.Sensor.V(3)
    """Mixed signal board"""

    PL = Temperature.Sensor.V(4)
    """Programmable logic"""

    PS = Temperature.Sensor.V(5)
    """Processing system"""

    SCANNER_SMALL = Temperature.Sensor.V(6)
    """Vertical mirror"""

    SCANNER_BIG = Temperature.Sensor.V(7)
    """Horizontal mirror"""


    SENSOR_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    FAILED_REASON_FIELD_NUMBER: builtins.int
    sensor: global___Temperature.Sensor.V = ...
    """Refer to [Temperature.Sensor](#blickfeld.protocol.status.Temperature.Sensor)"""

    value: builtins.float = ...
    """Unit: [degrees Celsius] – temperature value of the module."""

    failed_reason: typing.Text = ...
    """Error reason why the temperature cannot be read out."""

    def __init__(self,
        *,
        sensor : typing.Optional[global___Temperature.Sensor.V] = ...,
        value : typing.Optional[builtins.float] = ...,
        failed_reason : typing.Optional[typing.Text] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"data",b"data",u"failed_reason",b"failed_reason",u"sensor",b"sensor",u"value",b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"failed_reason",b"failed_reason",u"sensor",b"sensor",u"value",b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"data",b"data"]) -> typing.Optional[typing_extensions.Literal["value","failed_reason"]]: ...
global___Temperature = Temperature



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bf_proto/percept/common/metadata.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='bf_proto/percept/common/metadata.proto',
  package='blickfeld.percept.common',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&bf_proto/percept/common/metadata.proto\x12\x18\x62lickfeld.percept.common\x1a\x1fgoogle/protobuf/timestamp.proto\"j\n\rMessageHeader\x12\x14\n\x0cproject_uuid\x18\x01 \x01(\t\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cproject_name\x18\x03 \x01(\tb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_MESSAGEHEADER = _descriptor.Descriptor(
  name='MessageHeader',
  full_name='blickfeld.percept.common.MessageHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_uuid', full_name='blickfeld.percept.common.MessageHeader.project_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='blickfeld.percept.common.MessageHeader.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project_name', full_name='blickfeld.percept.common.MessageHeader.project_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=207,
)

_MESSAGEHEADER.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['MessageHeader'] = _MESSAGEHEADER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MessageHeader = _reflection.GeneratedProtocolMessageType('MessageHeader', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEHEADER,
  '__module__' : 'bf_proto.percept.common.metadata_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.common.MessageHeader)
  })
_sym_db.RegisterMessage(MessageHeader)


# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Secure(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Permissions(_Permissions, metaclass=_PermissionsEnumTypeWrapper):
        """do NOT change enum labels, they are used as strings in ssl certs"""
        pass
    class _Permissions:
        V = typing.NewType('V', builtins.int)
    class _PermissionsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Permissions.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        PUBLIC = Secure.Permissions.V(0)
        DEVELOPER = Secure.Permissions.V(1)

    PUBLIC = Secure.Permissions.V(0)
    DEVELOPER = Secure.Permissions.V(1)

    class CertType(_CertType, metaclass=_CertTypeEnumTypeWrapper):
        pass
    class _CertType:
        V = typing.NewType('V', builtins.int)
    class _CertTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CertType.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        CLIENT = Secure.CertType.V(0)
        CUBE = Secure.CertType.V(1)

    CLIENT = Secure.CertType.V(0)
    CUBE = Secure.CertType.V(1)

    PERMISSIONS_FIELD_NUMBER: builtins.int
    CERT_TYPE_FIELD_NUMBER: builtins.int
    VERSION_MAJOR_FIELD_NUMBER: builtins.int
    VERSION_MINOR_FIELD_NUMBER: builtins.int
    VERSION_PATCH_FIELD_NUMBER: builtins.int
    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___Secure.Permissions.V]: ...
    cert_type: global___Secure.CertType.V = ...
    version_major: builtins.int = ...
    version_minor: builtins.int = ...
    version_patch: builtins.int = ...
    def __init__(self,
        *,
        permissions : typing.Optional[typing.Iterable[global___Secure.Permissions.V]] = ...,
        cert_type : typing.Optional[global___Secure.CertType.V] = ...,
        version_major : typing.Optional[builtins.int] = ...,
        version_minor : typing.Optional[builtins.int] = ...,
        version_patch : typing.Optional[builtins.int] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"cert_type",b"cert_type",u"version_major",b"version_major",u"version_minor",b"version_minor",u"version_patch",b"version_patch"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"cert_type",b"cert_type",u"permissions",b"permissions",u"version_major",b"version_major",u"version_minor",b"version_minor",u"version_patch",b"version_patch"]) -> None: ...
global___Secure = Secure



from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()
long_description = (here / "README.md").read_text(encoding="utf-8")

setup(
    name="a42_proto",
    version="0.1.5",
    author="Alexander Baumann",
    author_email="alexander.baumann@hs-esslingen.de",
    description="Protobuf Python bindings for A42 sensor data",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/HSE-VSV/DataReaderA42",
    packages=find_packages(
        exclude=[
            "scripts",
            "scripts.*"
        ]
    ),
    python_requires=">=3.6",
    install_requires=[
        "protobuf==3.20.3",
    ],
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TimeSynchronization(google.protobuf.message.Message):
    """*
    > Introduced in BSL v2.18 and firmware v1.19

    This section defines the synchronization status of the server.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class State(_State, metaclass=_StateEnumTypeWrapper):
        pass
    class _State:
        V = typing.NewType('V', builtins.int)
    class _StateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_State.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        STOPPED = TimeSynchronization.State.V(1)
        INITIALIZING = TimeSynchronization.State.V(2)
        SYNCED = TimeSynchronization.State.V(3)
        FAILED = TimeSynchronization.State.V(4)

    STOPPED = TimeSynchronization.State.V(1)
    INITIALIZING = TimeSynchronization.State.V(2)
    SYNCED = TimeSynchronization.State.V(3)
    FAILED = TimeSynchronization.State.V(4)

    class PTP(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        STATE_FIELD_NUMBER: builtins.int
        CLOCK_ID_FIELD_NUMBER: builtins.int
        ONE_WAY_DELAY_FIELD_NUMBER: builtins.int
        SLAVE_TO_MASTER_FIELD_NUMBER: builtins.int
        MASTER_TO_SLAVE_FIELD_NUMBER: builtins.int
        OBSERVED_DRIFT_FIELD_NUMBER: builtins.int
        LAST_PACKET_RECEIVED_FIELD_NUMBER: builtins.int
        state: typing.Text = ...
        """*
        ONLY AVAILABLE FOR PTP, NTP doesnt have a state
        Follwing states can occur:
        init: Initializing,
        flt: Faulty,
        lstn_init: Listening (first time),
        lstn_reset: Listening (subsequent reset),
        pass: Passive (not best master, not announcing),
        uncl: Uncalibrated,
        slv: Worker,
        pmst: Pre-master,
        mst: Master (active),
        dsbl: Disabled,
        ? (unk): Unknown state
        """

        clock_id: typing.Text = ...
        """*
        TODO Find out for NTP!!
        Clock ID
        Port identity of the current best master, as defined by IEEE 1588 standard. This ID is the local clock's ID if the local clock is the best master.
        This parameter is displayed as clock_id or port (host). Port is the PTP clock port number, not the User Datagram Protocol (UDP) port numbers.
        The clock ID is an Extended Unique Identifier (EUI)-64 64-bit ID, converted from the 48-bit MAC address, by inserting 0xfffe at the middle of the MAC address.
        """

        one_way_delay: builtins.float = ...
        """*
        One-way delay
        Current value of one-way delay (or mean-path delay) in seconds, calculated by the ptpd daemon that is in the worker state from the delay request and delay response message exchange.
        Note: If this value remains at zero, it means that no delay response messages are being received, which might be because of a network issue.
        """

        slave_to_master: builtins.float = ...
        """*
        Slave to master
        Intermediate offset value (seconds) extracted from the delay request and delay response message exchange.
        This value is used for computing one-way delay. If the last value was rejected by a filter, the previous value is shown in the log file.
        This value is zero (0) if the delay response messages are not received.
        """

        master_to_slave: builtins.float = ...
        """*
        Master to slave
        Intermediate offset value (seconds) extracted from the sync messages. This value is used for computing the offset value from the master devices.
        If the last value was rejected by a filter, the previous value is shown in the log file.
        """

        observed_drift: builtins.float = ...
        """*
        Observed drift
        The frequency difference between the worker clock and the master clock as measured by the integral accumulator of the clock control proportional integral (PI) servo model.
        This value stabilizes when the clock offset value is stabilized, and this value is used to detect clock stability.
        """

        last_packet_received: typing.Text = ...
        """*
        Last packet Received
        This field shows which message was received last. It displays S for sync messages and D for delay response messages.
        If a worker device logs no D entries, it means that the worker device is not receiving delay response messages because of network issue.
        """

        def __init__(self,
            *,
            state : typing.Optional[typing.Text] = ...,
            clock_id : typing.Optional[typing.Text] = ...,
            one_way_delay : typing.Optional[builtins.float] = ...,
            slave_to_master : typing.Optional[builtins.float] = ...,
            master_to_slave : typing.Optional[builtins.float] = ...,
            observed_drift : typing.Optional[builtins.float] = ...,
            last_packet_received : typing.Optional[typing.Text] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"clock_id",b"clock_id",u"last_packet_received",b"last_packet_received",u"master_to_slave",b"master_to_slave",u"observed_drift",b"observed_drift",u"one_way_delay",b"one_way_delay",u"slave_to_master",b"slave_to_master",u"state",b"state"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"clock_id",b"clock_id",u"last_packet_received",b"last_packet_received",u"master_to_slave",b"master_to_slave",u"observed_drift",b"observed_drift",u"one_way_delay",b"one_way_delay",u"slave_to_master",b"slave_to_master",u"state",b"state"]) -> None: ...

    class NTP(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        FREQUENCY_OFFSET_FIELD_NUMBER: builtins.int
        RMS_JITTER_FIELD_NUMBER: builtins.int
        ALLAN_DEVIATION_FIELD_NUMBER: builtins.int
        CLOCK_DISCIPLINE_TIME_CONSTANT_FIELD_NUMBER: builtins.int
        frequency_offset: builtins.float = ...
        """frequency offset (parts per million - PPM) as in loopstats"""

        rms_jitter: builtins.float = ...
        """RMS jitter (seconds) as in loopstats"""

        allan_deviation: builtins.float = ...
        """Allan deviation (PPM) as in loopstats"""

        clock_discipline_time_constant: builtins.float = ...
        """clock discipline time constant as in loopstats"""

        def __init__(self,
            *,
            frequency_offset : typing.Optional[builtins.float] = ...,
            rms_jitter : typing.Optional[builtins.float] = ...,
            allan_deviation : typing.Optional[builtins.float] = ...,
            clock_discipline_time_constant : typing.Optional[builtins.float] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"allan_deviation",b"allan_deviation",u"clock_discipline_time_constant",b"clock_discipline_time_constant",u"frequency_offset",b"frequency_offset",u"rms_jitter",b"rms_jitter"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"allan_deviation",b"allan_deviation",u"clock_discipline_time_constant",b"clock_discipline_time_constant",u"frequency_offset",b"frequency_offset",u"rms_jitter",b"rms_jitter"]) -> None: ...

    STATE_FIELD_NUMBER: builtins.int
    OFFSET_FROM_MASTER_FIELD_NUMBER: builtins.int
    NTP_FIELD_NUMBER: builtins.int
    PTP_FIELD_NUMBER: builtins.int
    state: global___TimeSynchronization.State.V = ...
    offset_from_master: builtins.float = ...
    """*
    Current offset value from master device in seconds.
    NTP: time offset (seconds) in loopstats
    PTP:
    It is the main output of the PTP engine that is in the worker state.
    This value is the input for clock corrections in the clock servo algorithms. This value is typically measured when estimating the performance of the worker device.
    """

    @property
    def ntp(self) -> global___TimeSynchronization.NTP:
        """Refer to [NTP](#blickfeld.protocol.status.TimeSynchronization.NTP)"""
        pass
    @property
    def ptp(self) -> global___TimeSynchronization.PTP:
        """Refer to [PTP](#blickfeld.protocol.status.TimeSynchronization.PTP)"""
        pass
    def __init__(self,
        *,
        state : typing.Optional[global___TimeSynchronization.State.V] = ...,
        offset_from_master : typing.Optional[builtins.float] = ...,
        ntp : typing.Optional[global___TimeSynchronization.NTP] = ...,
        ptp : typing.Optional[global___TimeSynchronization.PTP] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"kind",b"kind",u"ntp",b"ntp",u"offset_from_master",b"offset_from_master",u"ptp",b"ptp",u"state",b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"kind",b"kind",u"ntp",b"ntp",u"offset_from_master",b"offset_from_master",u"ptp",b"ptp",u"state",b"state"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"kind",b"kind"]) -> typing.Optional[typing_extensions.Literal["ntp","ptp"]]: ...
global___TimeSynchronization = TimeSynchronization



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bf_proto.percept.common.geometry_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class PointCloudTransform(google.protobuf.message.Message):
    """*
    A message that contains point cloud transformation information
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SOURCE_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    TRANSFORM_FIELD_NUMBER: builtins.int
    source: typing.Text = ...
    """Source frame of the point cloud. This corresponds to user-defined name of the lidar."""

    target: typing.Text = ...
    """Target frame of the transform"""

    @property
    def transform(self) -> bf_proto.percept.common.geometry_pb2.Transform:
        """Rigid transformation"""
        pass
    def __init__(self,
        *,
        source : typing.Text = ...,
        target : typing.Text = ...,
        transform : typing.Optional[bf_proto.percept.common.geometry_pb2.Transform] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"transform",b"transform"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"source",b"source",u"target",b"target",u"transform",b"transform"]) -> None: ...
global___PointCloudTransform = PointCloudTransform



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/file/point_cloud.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from blickfeld import options_pb2 as blickfeld_dot_options__pb2
from blickfeld.data import point_cloud_pb2 as blickfeld_dot_data_dot_point__cloud__pb2
from blickfeld.data import frame_pb2 as blickfeld_dot_data_dot_frame__pb2
from blickfeld.config import scan_pattern_pb2 as blickfeld_dot_config_dot_scan__pattern__pb2
from blickfeld.file import general_pb2 as blickfeld_dot_file_dot_general__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/file/point_cloud.proto',
  package='blickfeld.protocol.file',
  syntax='proto2',
  serialized_options=b'\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n blickfeld/file/point_cloud.proto\x12\x17\x62lickfeld.protocol.file\x1a\x17\x62lickfeld/options.proto\x1a blickfeld/data/point_cloud.proto\x1a\x1a\x62lickfeld/data/frame.proto\x1a#blickfeld/config/scan_pattern.proto\x1a\x1c\x62lickfeld/file/general.proto\"\x94\x06\n\nPointCloud\x1a{\n\x06Header\x12@\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32*.blickfeld.protocol.data.PointCloud.HeaderB\x04\xb0\xb5\x18\x01\x12/\n\x06\x63lient\x18\x02 \x01(\x0b\x32\x1f.blickfeld.protocol.file.Client\x1a\x90\x03\n\x06\x46ooter\x12?\n\x05stats\x18\x01 \x01(\x0b\x32\x30.blickfeld.protocol.file.PointCloud.Footer.Stats\x12@\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x30.blickfeld.protocol.file.PointCloud.Footer.Event\x12\x14\n\x0cstop_time_ns\x18\x03 \x01(\x04\x1a\x8e\x01\n\x05Stats\x12I\n\x07\x63ounter\x18\x01 \x01(\x0b\x32\x38.blickfeld.protocol.file.PointCloud.Footer.Stats.Counter\x1a:\n\x07\x43ounter\x12\x0e\n\x06\x66rames\x18\x01 \x01(\x04\x12\x0e\n\x06points\x18\x02 \x01(\x04\x12\x0f\n\x07returns\x18\x03 \x01(\x04\x1a\\\n\x05\x45vent\x12\x15\n\rfrom_frame_id\x18\x01 \x01(\x04\x12<\n\x0cscan_pattern\x18\x02 \x01(\x0b\x32&.blickfeld.protocol.config.ScanPattern\x1a\x82\x01\n\x08Metadata\x12:\n\x06header\x18\x01 \x01(\x0b\x32*.blickfeld.protocol.file.PointCloud.Header\x12:\n\x06\x66ooter\x18\x02 \x01(\x0b\x32*.blickfeld.protocol.file.PointCloud.Footer\x1aq\n\x04\x44\x61ta\x12-\n\x05\x66rame\x18\x01 \x01(\x0b\x32\x1e.blickfeld.protocol.data.Frame\x12:\n\x06\x66ooter\x18\x02 \x01(\x0b\x32*.blickfeld.protocol.file.PointCloud.FooterB\x03\xf8\x01\x01'
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,blickfeld_dot_data_dot_point__cloud__pb2.DESCRIPTOR,blickfeld_dot_data_dot_frame__pb2.DESCRIPTOR,blickfeld_dot_config_dot_scan__pattern__pb2.DESCRIPTOR,blickfeld_dot_file_dot_general__pb2.DESCRIPTOR,])




_POINTCLOUD_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='blickfeld.protocol.file.PointCloud.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='blickfeld.protocol.file.PointCloud.Header.device', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client', full_name='blickfeld.protocol.file.PointCloud.Header.client', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=353,
)

_POINTCLOUD_FOOTER_STATS_COUNTER = _descriptor.Descriptor(
  name='Counter',
  full_name='blickfeld.protocol.file.PointCloud.Footer.Stats.Counter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frames', full_name='blickfeld.protocol.file.PointCloud.Footer.Stats.Counter.frames', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='points', full_name='blickfeld.protocol.file.PointCloud.Footer.Stats.Counter.points', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='returns', full_name='blickfeld.protocol.file.PointCloud.Footer.Stats.Counter.returns', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=604,
  serialized_end=662,
)

_POINTCLOUD_FOOTER_STATS = _descriptor.Descriptor(
  name='Stats',
  full_name='blickfeld.protocol.file.PointCloud.Footer.Stats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='counter', full_name='blickfeld.protocol.file.PointCloud.Footer.Stats.counter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_POINTCLOUD_FOOTER_STATS_COUNTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=662,
)

_POINTCLOUD_FOOTER_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='blickfeld.protocol.file.PointCloud.Footer.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_frame_id', full_name='blickfeld.protocol.file.PointCloud.Footer.Event.from_frame_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scan_pattern', full_name='blickfeld.protocol.file.PointCloud.Footer.Event.scan_pattern', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=664,
  serialized_end=756,
)

_POINTCLOUD_FOOTER = _descriptor.Descriptor(
  name='Footer',
  full_name='blickfeld.protocol.file.PointCloud.Footer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats', full_name='blickfeld.protocol.file.PointCloud.Footer.stats', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events', full_name='blickfeld.protocol.file.PointCloud.Footer.events', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_time_ns', full_name='blickfeld.protocol.file.PointCloud.Footer.stop_time_ns', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_POINTCLOUD_FOOTER_STATS, _POINTCLOUD_FOOTER_EVENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=756,
)

_POINTCLOUD_METADATA = _descriptor.Descriptor(
  name='Metadata',
  full_name='blickfeld.protocol.file.PointCloud.Metadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='blickfeld.protocol.file.PointCloud.Metadata.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='footer', full_name='blickfeld.protocol.file.PointCloud.Metadata.footer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=759,
  serialized_end=889,
)

_POINTCLOUD_DATA = _descriptor.Descriptor(
  name='Data',
  full_name='blickfeld.protocol.file.PointCloud.Data',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame', full_name='blickfeld.protocol.file.PointCloud.Data.frame', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='footer', full_name='blickfeld.protocol.file.PointCloud.Data.footer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=891,
  serialized_end=1004,
)

_POINTCLOUD = _descriptor.Descriptor(
  name='PointCloud',
  full_name='blickfeld.protocol.file.PointCloud',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_POINTCLOUD_HEADER, _POINTCLOUD_FOOTER, _POINTCLOUD_METADATA, _POINTCLOUD_DATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=216,
  serialized_end=1004,
)

_POINTCLOUD_HEADER.fields_by_name['device'].message_type = blickfeld_dot_data_dot_point__cloud__pb2._POINTCLOUD_HEADER
_POINTCLOUD_HEADER.fields_by_name['client'].message_type = blickfeld_dot_file_dot_general__pb2._CLIENT
_POINTCLOUD_HEADER.containing_type = _POINTCLOUD
_POINTCLOUD_FOOTER_STATS_COUNTER.containing_type = _POINTCLOUD_FOOTER_STATS
_POINTCLOUD_FOOTER_STATS.fields_by_name['counter'].message_type = _POINTCLOUD_FOOTER_STATS_COUNTER
_POINTCLOUD_FOOTER_STATS.containing_type = _POINTCLOUD_FOOTER
_POINTCLOUD_FOOTER_EVENT.fields_by_name['scan_pattern'].message_type = blickfeld_dot_config_dot_scan__pattern__pb2._SCANPATTERN
_POINTCLOUD_FOOTER_EVENT.containing_type = _POINTCLOUD_FOOTER
_POINTCLOUD_FOOTER.fields_by_name['stats'].message_type = _POINTCLOUD_FOOTER_STATS
_POINTCLOUD_FOOTER.fields_by_name['events'].message_type = _POINTCLOUD_FOOTER_EVENT
_POINTCLOUD_FOOTER.containing_type = _POINTCLOUD
_POINTCLOUD_METADATA.fields_by_name['header'].message_type = _POINTCLOUD_HEADER
_POINTCLOUD_METADATA.fields_by_name['footer'].message_type = _POINTCLOUD_FOOTER
_POINTCLOUD_METADATA.containing_type = _POINTCLOUD
_POINTCLOUD_DATA.fields_by_name['frame'].message_type = blickfeld_dot_data_dot_frame__pb2._FRAME
_POINTCLOUD_DATA.fields_by_name['footer'].message_type = _POINTCLOUD_FOOTER
_POINTCLOUD_DATA.containing_type = _POINTCLOUD
DESCRIPTOR.message_types_by_name['PointCloud'] = _POINTCLOUD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PointCloud = _reflection.GeneratedProtocolMessageType('PointCloud', (_message.Message,), {

  'Header' : _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
    'DESCRIPTOR' : _POINTCLOUD_HEADER,
    '__module__' : 'blickfeld.file.point_cloud_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.file.PointCloud.Header)
    })
  ,

  'Footer' : _reflection.GeneratedProtocolMessageType('Footer', (_message.Message,), {

    'Stats' : _reflection.GeneratedProtocolMessageType('Stats', (_message.Message,), {

      'Counter' : _reflection.GeneratedProtocolMessageType('Counter', (_message.Message,), {
        'DESCRIPTOR' : _POINTCLOUD_FOOTER_STATS_COUNTER,
        '__module__' : 'blickfeld.file.point_cloud_pb2'
        # @@protoc_insertion_point(class_scope:blickfeld.protocol.file.PointCloud.Footer.Stats.Counter)
        })
      ,
      'DESCRIPTOR' : _POINTCLOUD_FOOTER_STATS,
      '__module__' : 'blickfeld.file.point_cloud_pb2'
      # @@protoc_insertion_point(class_scope:blickfeld.protocol.file.PointCloud.Footer.Stats)
      })
    ,

    'Event' : _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
      'DESCRIPTOR' : _POINTCLOUD_FOOTER_EVENT,
      '__module__' : 'blickfeld.file.point_cloud_pb2'
      # @@protoc_insertion_point(class_scope:blickfeld.protocol.file.PointCloud.Footer.Event)
      })
    ,
    'DESCRIPTOR' : _POINTCLOUD_FOOTER,
    '__module__' : 'blickfeld.file.point_cloud_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.file.PointCloud.Footer)
    })
  ,

  'Metadata' : _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {
    'DESCRIPTOR' : _POINTCLOUD_METADATA,
    '__module__' : 'blickfeld.file.point_cloud_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.file.PointCloud.Metadata)
    })
  ,

  'Data' : _reflection.GeneratedProtocolMessageType('Data', (_message.Message,), {
    'DESCRIPTOR' : _POINTCLOUD_DATA,
    '__module__' : 'blickfeld.file.point_cloud_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.file.PointCloud.Data)
    })
  ,
  'DESCRIPTOR' : _POINTCLOUD,
  '__module__' : 'blickfeld.file.point_cloud_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.file.PointCloud)
  })
_sym_db.RegisterMessage(PointCloud)
_sym_db.RegisterMessage(PointCloud.Header)
_sym_db.RegisterMessage(PointCloud.Footer)
_sym_db.RegisterMessage(PointCloud.Footer.Stats)
_sym_db.RegisterMessage(PointCloud.Footer.Stats.Counter)
_sym_db.RegisterMessage(PointCloud.Footer.Event)
_sym_db.RegisterMessage(PointCloud.Metadata)
_sym_db.RegisterMessage(PointCloud.Data)


DESCRIPTOR._options = None
_POINTCLOUD_HEADER.fields_by_name['device']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bf_proto/percept/output/output.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bf_proto.percept.common import metadata_pb2 as bf__proto_dot_percept_dot_common_dot_metadata__pb2
from bf_proto.percept.data import object_pb2 as bf__proto_dot_percept_dot_data_dot_object__pb2
from bf_proto.percept.data import state_pb2 as bf__proto_dot_percept_dot_data_dot_state__pb2
from bf_proto.percept.data import zone_algorithm_pb2 as bf__proto_dot_percept_dot_data_dot_zone__algorithm__pb2
from bf_proto.percept.data import point_cloud_transform_pb2 as bf__proto_dot_percept_dot_data_dot_point__cloud__transform__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='bf_proto/percept/output/output.proto',
  package='blickfeld.percept.output',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$bf_proto/percept/output/output.proto\x12\x18\x62lickfeld.percept.output\x1a&bf_proto/percept/common/metadata.proto\x1a\"bf_proto/percept/data/object.proto\x1a!bf_proto/percept/data/state.proto\x1a*bf_proto/percept/data/zone_algorithm.proto\x1a\x31\x62\x66_proto/percept/data/point_cloud_transform.proto\"s\n\tStateList\x12\x37\n\x06header\x18\x01 \x01(\x0b\x32\'.blickfeld.percept.common.MessageHeader\x12-\n\x06states\x18\x02 \x03(\x0b\x32\x1d.blickfeld.percept.data.State\"\x8f\x01\n\nObjectList\x12\x37\n\x06header\x18\x01 \x01(\x0b\x32\'.blickfeld.percept.common.MessageHeader\x12\x17\n\x0freference_frame\x18\x02 \x01(\t\x12/\n\x07objects\x18\x03 \x03(\x0b\x32\x1e.blickfeld.percept.data.Object\"\xa5\x01\n\x11ZoneAlgorithmList\x12\x37\n\x06header\x18\x01 \x01(\x0b\x32\'.blickfeld.percept.common.MessageHeader\x12\x17\n\x0freference_frame\x18\x02 \x01(\t\x12>\n\x0fzone_algorithms\x18\x03 \x03(\x0b\x32%.blickfeld.percept.data.ZoneAlgorithm\"\x9f\x01\n\x17PointCloudTransformList\x12\x37\n\x06header\x18\x01 \x01(\x0b\x32\'.blickfeld.percept.common.MessageHeader\x12K\n\x16point_cloud_transforms\x18\x02 \x03(\x0b\x32+.blickfeld.percept.data.PointCloudTransformb\x06proto3'
  ,
  dependencies=[bf__proto_dot_percept_dot_common_dot_metadata__pb2.DESCRIPTOR,bf__proto_dot_percept_dot_data_dot_object__pb2.DESCRIPTOR,bf__proto_dot_percept_dot_data_dot_state__pb2.DESCRIPTOR,bf__proto_dot_percept_dot_data_dot_zone__algorithm__pb2.DESCRIPTOR,bf__proto_dot_percept_dot_data_dot_point__cloud__transform__pb2.DESCRIPTOR,])




_STATELIST = _descriptor.Descriptor(
  name='StateList',
  full_name='blickfeld.percept.output.StateList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='blickfeld.percept.output.StateList.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='states', full_name='blickfeld.percept.output.StateList.states', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=387,
)


_OBJECTLIST = _descriptor.Descriptor(
  name='ObjectList',
  full_name='blickfeld.percept.output.ObjectList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='blickfeld.percept.output.ObjectList.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_frame', full_name='blickfeld.percept.output.ObjectList.reference_frame', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='objects', full_name='blickfeld.percept.output.ObjectList.objects', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=390,
  serialized_end=533,
)


_ZONEALGORITHMLIST = _descriptor.Descriptor(
  name='ZoneAlgorithmList',
  full_name='blickfeld.percept.output.ZoneAlgorithmList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='blickfeld.percept.output.ZoneAlgorithmList.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_frame', full_name='blickfeld.percept.output.ZoneAlgorithmList.reference_frame', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_algorithms', full_name='blickfeld.percept.output.ZoneAlgorithmList.zone_algorithms', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=701,
)


_POINTCLOUDTRANSFORMLIST = _descriptor.Descriptor(
  name='PointCloudTransformList',
  full_name='blickfeld.percept.output.PointCloudTransformList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='blickfeld.percept.output.PointCloudTransformList.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_cloud_transforms', full_name='blickfeld.percept.output.PointCloudTransformList.point_cloud_transforms', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=704,
  serialized_end=863,
)

_STATELIST.fields_by_name['header'].message_type = bf__proto_dot_percept_dot_common_dot_metadata__pb2._MESSAGEHEADER
_STATELIST.fields_by_name['states'].message_type = bf__proto_dot_percept_dot_data_dot_state__pb2._STATE
_OBJECTLIST.fields_by_name['header'].message_type = bf__proto_dot_percept_dot_common_dot_metadata__pb2._MESSAGEHEADER
_OBJECTLIST.fields_by_name['objects'].message_type = bf__proto_dot_percept_dot_data_dot_object__pb2._OBJECT
_ZONEALGORITHMLIST.fields_by_name['header'].message_type = bf__proto_dot_percept_dot_common_dot_metadata__pb2._MESSAGEHEADER
_ZONEALGORITHMLIST.fields_by_name['zone_algorithms'].message_type = bf__proto_dot_percept_dot_data_dot_zone__algorithm__pb2._ZONEALGORITHM
_POINTCLOUDTRANSFORMLIST.fields_by_name['header'].message_type = bf__proto_dot_percept_dot_common_dot_metadata__pb2._MESSAGEHEADER
_POINTCLOUDTRANSFORMLIST.fields_by_name['point_cloud_transforms'].message_type = bf__proto_dot_percept_dot_data_dot_point__cloud__transform__pb2._POINTCLOUDTRANSFORM
DESCRIPTOR.message_types_by_name['StateList'] = _STATELIST
DESCRIPTOR.message_types_by_name['ObjectList'] = _OBJECTLIST
DESCRIPTOR.message_types_by_name['ZoneAlgorithmList'] = _ZONEALGORITHMLIST
DESCRIPTOR.message_types_by_name['PointCloudTransformList'] = _POINTCLOUDTRANSFORMLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StateList = _reflection.GeneratedProtocolMessageType('StateList', (_message.Message,), {
  'DESCRIPTOR' : _STATELIST,
  '__module__' : 'bf_proto.percept.output.output_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.output.StateList)
  })
_sym_db.RegisterMessage(StateList)

ObjectList = _reflection.GeneratedProtocolMessageType('ObjectList', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTLIST,
  '__module__' : 'bf_proto.percept.output.output_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.output.ObjectList)
  })
_sym_db.RegisterMessage(ObjectList)

ZoneAlgorithmList = _reflection.GeneratedProtocolMessageType('ZoneAlgorithmList', (_message.Message,), {
  'DESCRIPTOR' : _ZONEALGORITHMLIST,
  '__module__' : 'bf_proto.percept.output.output_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.output.ZoneAlgorithmList)
  })
_sym_db.RegisterMessage(ZoneAlgorithmList)

PointCloudTransformList = _reflection.GeneratedProtocolMessageType('PointCloudTransformList', (_message.Message,), {
  'DESCRIPTOR' : _POINTCLOUDTRANSFORMLIST,
  '__module__' : 'bf_proto.percept.output.output_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.output.PointCloudTransformList)
  })
_sym_db.RegisterMessage(PointCloudTransformList)


# @@protoc_insertion_point(module_scope)
